==> keybase-1.0.39.tar.gz: client-1.0.39/shared/stories/stories.js <==
// @flow
import avatar from '../common-adapters/avatar.stories'
import buttonBar from '../common-adapters/button-bar.stories'
import button from '../common-adapters/button.stories'
import box from '../common-adapters/box.stories'
import chatInboxRow from '../chat/inbox/row/index.stories'
import chatInfoPanel from '../chat/conversation/info-panel/index.stories'
import chatInfoPanelNotifications from '../chat/conversation/info-panel/notifications/index.stories'
import chatList from '../chat/conversation/list/index.stories'
import chatCreateChannel from '../chat/create-channel/index.stories'
import chatManageChannels from '../chat/manage-channels/index.stories'
import chatHud from '../chat/hud/index.stories'
import checkbox from '../common-adapters/checkbox.stories'
import dropdown from '../common-adapters/dropdown.stories'
import git from '../git/index.stories'
import icon from '../common-adapters/icon.stories'
import radiobutton from '../common-adapters/radio-button.stories'
import roles from '../teams/role-picker/index.stories'
import search from '../search/search.stories'
import teams from '../teams/index.stories'
import text from '../common-adapters/text.stories'
import editTeamDescription from '../teams/edit-team-description/index.stories'

const stories = {
  avatar,
  box,
  button,
  buttonBar,
  chatCreateChannel,
  chatHud,
  chatInboxRow,
  chatInfoPanel,
  chatInfoPanelNotifications,
  chatList,
  chatManageChannels,
  checkbox,
  dropdown,
  editTeamDescription,
  git,
  icon,
  radiobutton,
  roles,
  search,
  teams,
  text,
}

export default stories

==> keybase-1.0.41.tar.gz: client-1.0.41/shared/stories/stories.js <==
// @flow
import avatar from '../common-adapters/avatar.stories'
import buttonBar from '../common-adapters/button-bar.stories'
import button from '../common-adapters/button.stories'
import box from '../common-adapters/box.stories'
import chatInboxRow from '../chat/inbox/row/index.stories'
import chatInfoPanel from '../chat/conversation/info-panel/index.stories'
import chatInfoPanelNotifications from '../chat/conversation/info-panel/notifications/index.stories'
import chatList from '../chat/conversation/list/index.stories'
import chatCreateChannel from '../chat/create-channel/index.stories'
import chatManageChannels from '../chat/manage-channels/index.stories'
import chatChannelMentionHud from '../chat/channel-mention-hud/index.stories'
import chatUserMentionHud from '../chat/user-mention-hud/index.stories'
import checkbox from '../common-adapters/checkbox.stories'
import devices from '../devices/index.stories'
import dropdown from '../common-adapters/dropdown.stories'
import git from '../git/index.stories'
import icon from '../common-adapters/icon.stories'
import radiobutton from '../common-adapters/radio-button.stories'
import roles from '../teams/role-picker/index.stories'
import search from '../search/search.stories'
import teams from '../teams/index.stories'
import text from '../common-adapters/text.stories'
import editTeamDescription from '../teams/edit-team-description/index.stories'
import peopleTask from '../people/task/index.stories'
import peopleFollowNotification from '../people/follow-notification/index.stories'
import peopleFollowSuggestions from '../people/follow-suggestions/index.stories'
import fs from '../fs/index.stories.js'

const stories = {
  avatar,
  box,
  button,
  buttonBar,
  chatChannelMentionHud,
  chatCreateChannel,
  chatInboxRow,
  chatInfoPanel,
  chatInfoPanelNotifications,
  chatList,
  chatManageChannels,
  chatUserMentionHud,
  checkbox,
  devices,
  dropdown,
  editTeamDescription,
  fs,
  git,
  icon,
  peopleTask,
  peopleFollowNotification,
  peopleFollowSuggestions,
  radiobutton,
  roles,
  search,
  teams,
  text,
}

export default stories
